/*
Replication Code For "Quantal Response and Nonequilibrium Beliefs Explain Overbidding 
in Maximum-Value Auctions" by Colin Camerer, Salvatore Nunnari and Thomas R. Palfrey
*/

* Replication of figures and tables for data collected by Camerer, Nunnari, and Palfrey

clear
use "FINALDATA-CALTECH.dta"
drop session totalprofit1 profit participate
set more off
rename profit1 profit

* CODEBOOK
* sessionid: numerical ID for session (1, 2, 3)
* period: ID for period in a given session (1-22); periods 1-11 are auctions against other subjects; periods 12-22 are against the computer (which mimic's one's own past strategy)
* subject: ID for subject in a given session (1-12 in session 1, 1-18 in session 2, 1-16 in session 3)
* group: ID for pair of subjects playing together in a given period (1-6 in session 1, 1-9 in session 2, 1-8 in session 3)
* x: signal received by subject in this period
* x_other: signal received by subject's opponent in this period
* v: object's value in this period (maximum of two signals)
* bid: subject's bid in this period
* bid_other: subject's opponent bid in this period
* profit: subject's payoff in this period

egen subjectid=concat(sessionid subject), punct(_)
gen part=1
replace part=2 if period>11

gen yline3=x
set scheme s1color

* Figure 1a: bids as a function of private signal values in Phase I 
* Bids above 15 are not shown. 
*The continuous line is the median bid as a function of private signal (considering all bids).
scatter bid x if bid<15.01 & part==1, msize(*.75) xtitle("Private Signal") ytitle("Bid") mcolor(edkblue) || ///
line yline3 x, sort lcolor(black) lpattern(longdash) || ///
mband bid x if part==1, ///
legend(label(1 "Bid") on) legend(label(3 "Uncensored Median Bid") on) legend(label(2 "Bid=Signal") on) legend(rows(1)) title("Censored Bids") lwidth(medthick) lcolor(red)

* Figure 1b: bids as a function of private signal values in Phase II
* Bids above 15 are not shown. 
*The continuous line is the median bid as a function of private signal (considering all bids).
scatter bid x if bid<15.01 & part==2, msize(*.75) xtitle("Private Signal") ytitle("Bid") mcolor(edkblue) || ///
line yline3 x, sort lcolor(black) lpattern(longdash) || ///
mband bid x if part==2, ///
legend(label(1 "Bid") on) legend(label(3 "Uncensored Median Bid") on) legend(label(2 "Bid=Signal") on) legend(rows(1)) title("Censored Bids") lwidth(medthick) lcolor(red)

* Figure 3: CDF of Mean bids, Phase I
preserve
keep if part==1
bys subjectid: egen meanbid=mean(bid)
bys subjectid: keep if _n==1
cumul meanbid, gen (cmeanbid)
sort meanbid
line cmeanbid meanbid
restore

* Table 4: Summary Statistics of Bids
su bid if part==1, detail
su bid if part==2, detail

* Figure 8a: Bids as a function of signals, Phase 1, all bids
gen logbid=log(bid)
replace logbid=-5 if bid==0
gen yline=2.302585
gen yline2=log(x)
replace yline2=-5 if x==0

set scheme s1color

scatter logbid x if part==1, msize(*.75) xtitle("Private Signal") ytitle("Log(Bid)") mcolor(edkblue) || ///
line yline x, sort lcolor(red) || line yline2 x, sort lcolor(black) lpattern(longdash) yscale(range(-5 14)) ///
legend(label(1 "Log(Bid)") on) legend(label(2 "Bid=10") on) legend(label(3 "Bid=Signal") on) legend(rows(1)) title("All Bids")

* Replication of figures and tables for data collected by Ivanov, Levin and Niederle
clear
use "FINALDATA-ILN-052310.dta", clear
drop totalprofitexcludingcurrentperio

* CODEBOOK
* sessionid: numerical ID for session (0-6)
* period: ID for period in a given session (1-22); periods 1-11 are auctions against other subjects; periods 12-22 are against the computer (which mimic's one's own past strategy)
* subject: unique ID for subject in the experiment
* Subjects 1-26 are from the pilot for the Baseline on 07/11/07 (design was a bit different from the Baseline); these subjects are excluded from the analysis in the paper
* Subjects 27-46 are from baseline on 07/23/07;
* Subjects 47-70 are from baseline on 07/25/07 morning;
* Subjects 71-88 are from baseline on 07/31/07 morning;
* Subjects 89-114 are from MinBid treatment on afternoon 07/25/07;
* Subjects 115-142 are from ShowBidFns treatment on 07/26/07;
* Subjects 143-160 are from ShowBidFns treatment on 07/31/07 afternoon;
* group: ID for pair of subjects playing together in a given period (1-6 in session 1, 1-9 in session 2, 1-8 in session 3)
* x: signal received by subject in this period
* x_other: signal received by subject's opponent in this period
* v: object's value in this period (maximum of two signals)
* bid: subject's bid in this period
* bid_other: subject's opponent bid in this period
* profit: subject's payoff in this period
* baseline: dummy for Baseline treatment
* minbid: dummy for MinBid treatment
* showbid: dummy for ShowBid treatment
* phase: experiment part; periods 1-11 are Phase 1 (auctions against other subjects); periods 12-22 are Phase 2 (auctions against the computer which mimic's one's own past strategy)

* Table 4: Summary Statistics of Bids
su bid if phase==1, detail
su bid if phase==2, detail

* Figure 8b: Bids as a function of signals, Phase 1, all bids
gen logbid=log(bid)
replace logbid=-5 if bid==0
gen yline=2.302585
gen yline2=log(x)
gen yline3=x
replace yline2=-5 if x==0

set scheme s1color

scatter logbid x if phase==1, msize(*.75) xtitle("Private Signal") ytitle("Log(Bid)") mcolor(edkblue) || ///
line yline x, sort lcolor(red) || line yline2 x, sort lcolor(black) lpattern(longdash) yscale(range(-5 14)) ///
legend(label(1 "Log(Bid)") on) legend(label(2 "Bid=10") on) legend(label(3 "Bid=Signal") on) legend(rows(1)) title("All Bids")

